QuadWindowExpansionStrategy

Enum QuadWindowExpansionStrategy 

pub enum QuadWindowExpansionStrategy<ImC> {
    None,
    Even(usize),
    UniformMobility((f64, f64), Option<Arc<ImC>>),
    UniformScan((usize, usize)),
}
Strategy for expanding quadrupole settings

This enum is used to determine how to expand quadrupole settings when reading in DIA data. And exporting spectra (not frames RN).

Variants

For example if we have a window with scan start 50 and end 500

  • None - Do not expand quadrupole settings; use the original settings
  • Even(usize) - Split the quadrupole settings into usize evenly spaced subwindows; e.g. if usize is 2, the window will be split into 2 subwindows of equal width.
  • UniformMobility(SpanStep) - Split the quadrupole settings into subwindows of width SpanStep.0 and step SpanStep.1 in ion mobility space. e.g. if SpanStep is (0.05, 0.02), the window will be split into subwindows of width 0.05 and step 0.02 between their in the mobility dimension.
  • UniformScan(SpanStep) - Split the quadrupole settings into subwindows of width SpanStep.0 and step SpanStep.1 in scan number space. e.g. if SpanStep is (100, 80), the window will be split into subwindows of width 100 and step 80 between their in the scan number.

Variants



None



Even(usize)



UniformMobility((f64, f64), Option<Arc<ImC>>)



UniformScan((usize, usize))